@@ -1,4 +1,5 @@
 from .gpcm import GPCM
 from .grm import GRM
 
-__all__ = ["GRM", "GPCM"]
+__all__ = ["GRM",
+           "GPCM"]
